Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(257)

Unified Diff: chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.h

Issue 2862003004: Mac: Fix infobar anchor under Harmony. (Closed)
Patch Set: s/. I/ i/ Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.h
diff --git a/chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.h b/chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.h
index 5bfd53c7cbb806eb91635bc631c0deb1046d94a9..ab747156d500dd1f0962921e4c6db8b8fb6f7996 100644
--- a/chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.h
+++ b/chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.h
@@ -108,10 +108,13 @@ class LocationBarViewMac : public LocationBar,
// save credit card bubble to aim at.
NSPoint GetSaveCreditCardBubblePoint() const;
// Get the point in window coordinates in the security icon at which the page
// info bubble aims.
NSPoint GetPageInfoBubblePoint() const;
+ // Get the point in window coordinates in the security icon at which infobar
+ // arrows should point.
+ NSPoint GetInfoBarAnchorPoint() const;
+
// When any image decorations change, call this to ensure everything is
// redrawn and laid out if necessary.
void OnDecorationsChanged();
@@ -108,10 +108,13 @@ class LocationBarViewMac : public LocationBar,
// save credit card bubble to aim at.
NSPoint GetSaveCreditCardBubblePoint() const;
- // Get the point in window coordinates in the security icon at which the page
- // info bubble aims.
+ // Get the point in window coordinates for the page info bubble anchor.
NSPoint GetPageInfoBubblePoint() const;

Powered by Google App Engine
This is Rietveld 408576698